beamprofiler.niso.characterizing\_parameters
============================================

.. automodule:: beamprofiler.niso.characterizing_parameters

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      clip_level_beam_width
      clip_level_edge_width
      plateau_uniformity
      top_hat_factor
   
   

   
   
   

   
   
   



